LOCAL loExc AS EXCEPTION
TRY
*!* Set up the initial environment
	DO SetCommands

*!* Bring up the application form
	DO FORM wds

*!* Start event processing loop
	READ EVENTS
CATCH TO loExc
	MESSAGEBOX(ErrorReporting(loExc, 0),64,"Problem Encountered")
ENDTRY

********************
PROCEDURE SetCommands
********************
	LOCAL lcPath
	SET BELL ON && Turns the computer bell on
	SET CENTURY ON && Specifies a four-digit year in a format that includes 10 characters
	SET CONSOLE OFF && Disables output to the main Visual FoxPro window or to the active user-defined window from within programs
	SET DELETED ON && Specifies that commands that operate on records, including records in related tables, using a scope ignore records that are marked for deletion
	SET ESCAPE OFF && Pressing the ESC key interrupts program and command execution
	SET EXCLUSIVE OFF && Specifies that tables are opened for shared use on a network
	SET HOURS TO 12 && Sets the system clock to a 12-hour time format
	SET MULTILOCKS ON && Required for row or table buffering and allows multiple records to be locked using LOCK( ) or RLOCK( )
	SET REFRESH TO 5,3 && Frequency (in seconds) to update a browse window or memo editing window, or to refresh local memory buffers - 1st parameter is for local data, 2nd parameter is for network data
	SET REPORTBEHAVIOR 90 && Using the new reporting engine features
	_REPORTOUTPUT = "ReportOutput.app" && Designate application to use for report output
	_REPORTPREVIEW = "ReportPreview.app" && Designate application to use for report previewing
	SET REPROCESS TO 5 SECONDS && How long will Visual FoxPro attempt to lock a file or record after an unsuccessful locking attempt
	SET SECONDS OFF && Specifies that seconds are not displayed in the time portion of a DateTime value
	SET STATUS BAR ON && Displays the graphical status bar at the bottom of the _screen
	SET SYSMENU OFF && Turn off the default system menu that Visual FoxPro uses
	SET TALK OFF && Prevents talk from being sent to the main Visual FoxPro window, the system message window, the graphical status bar, or a user-defined window
	IF _VFP.STARTMODE = 0  && running inside the Visual FoxPro IDE
		m.lcPath = LEFT(SYS(16,0), RAT("\", SYS(16,0), 2))
		SET DEFAULT TO (m.lcPath) && Specifies the default drive and directory
		SET PATH TO (m.lcPath + ";Data\;Forms\;Help\;Images\;Libs\;Menus\;Progs\;Reports\") && Specifies a path for file searches
		ON SHUTDOWN Cancel
	ELSE
		m.lcPath = JUSTPATH(SYS(16,0))
		SET DEFAULT TO (m.lcPath) && Specifies the default drive and directory
		SET PATH TO (m.lcPath + "Data\;Help\;Images\") && Specifies a path for file searches
		ON SHUTDOWN Quit
	ENDIF
ENDPROC && SetCommands

********************
FUNCTION ErrorReporting(toExc AS EXCEPTION, tnLevel)
********************
	LOCAL lcErrorInfo, lcPadding
	lcPadding = REPLICATE(CHR(9), tnLevel)
	lcErrorInfo = lcPadding + [Exception Object ]  + TRANSFORM(tnLevel) + [:]+ CHR(13) + ;
		lcPadding + [  ErrorNo: ] + TRANSFORM(toExc.ERRORNO)  + CHR(13) + ;
		lcPadding + [  LineNo: ] + TRANSFORM(toExc.LINENO)   + CHR(13) + ;
		lcPadding + [  Message: ] + toExc.MESSAGE   + CHR(13) + ;
		lcPadding + [  Procedure: ] + toExc.PROCEDURE   + CHR(13) + ;
		lcPadding + [  Details: ] + toExc.DETAILS   + CHR(13) + ;
		lcPadding + [  StackLevel: ] + TRANSFORM(toExc.STACKLEVEL)   + CHR(13) + ;
		lcPadding + [  LineContents: ] + toExc.LINECONTENTS   + CHR(13) + ;
		lcPadding + [  Comments: ] + toExc.COMMENT   + CHR(13) + CHR(13)
	IF TYPE("toExc.UserValue") = "O"
		lcErrorInfo = lcErrorInfo + ErrorReporting(toExc.USERVALUE, tnLevel + 1)
	ENDIF
	RETURN lcErrorInfo
ENDPROC && ErrorReporting
